Internal Functions
==================

This page details various internal functions within CSET. Most people should
never have to worry about these, but they are documented here for the
convenience of those developing CSET.

CSET.operators
--------------

.. automodule:: CSET.operators
   :members:

CSET.operators._utils
---------------------

.. automodule:: CSET.operators._utils
   :members:

CSET.recipes
------------

.. automodule:: CSET.recipes
   :members:

CSET.graph
----------

.. automodule:: CSET.graph
   :members:

CSET._common
------------

.. note::

    While no functions documented on this page are part of any API promise, the
    functions inside _common are especially liable to change without any kind of
    notice.

.. automodule:: CSET._common
   :members:
